import { z } from "zod";
import { useForm } from "react-hook-form";
import { zodResolver } from "@hookform/resolvers/zod";
import { Button } from "@/components/ui/button";
import
	{
		Form,
		FormControl, FormField,
		FormItem,
		FormLabel,
		FormMessage
	} from "@/components/ui/form";
import { Input } from "@/components/ui/input";
import useAuth from "@/hooks/useAuth";

// const languages = [
// 	{ label: "English", value: "en" },
// 	{ label: "French", value: "fr" },
// 	{ label: "German", value: "de" },
// 	{ label: "Spanish", value: "es" },
// 	{ label: "Portuguese", value: "pt" },
// 	{ label: "Russian", value: "ru" },
// 	{ label: "Japanese", value: "ja" },
// 	{ label: "Korean", value: "ko" },
// 	{ label: "Chinese", value: "zh" }
// ] as const;

const accountFormSchema = z.object({
	username: z.string().min(3).max(30),
	email: z.string().email(),
	phone_number: z.string(),
	// password: z.string().min(8).max(128),
	first_name: z.string().optional(),
	last_name: z.string().optional(),
	// dob: z.date({
	// 	required_error: "A date of birth is required."
	// }),
	// language: z.string({
	// 	required_error: "Please select a language."
	// })
});

type AccountFormValues = z.infer<typeof accountFormSchema>;

export function AccountForm() {
	const { updateAccountMutation, user } = useAuth();

	const form = useForm<AccountFormValues>({
		resolver: zodResolver(accountFormSchema)
	});

	function onSubmit(data: AccountFormValues) {
		updateAccountMutation.mutate({
			email: data.email,
			// password: data.password,
			password: "null",
			phone_number: data.phone_number,
			username: data.username,
			first_name: data.first_name,
			last_name: data.last_name
		});
	}

	return (
		<Form {...form}>
			<form onSubmit={form.handleSubmit(onSubmit)} className="space-y-8">
				<FormField
					control={form.control}
					name="username"
					render={({ field }) => (
						<FormItem>
							<FormLabel>Username</FormLabel>
							<FormControl>
								<Input placeholder="Your username" defaultValue={user?.username} {...field} />
							</FormControl>
							<FormMessage />
						</FormItem>
					)}
				/>
				<FormField
					control={form.control}
					name="email"
					render={({ field }) => (
						<FormItem>
							<FormLabel>Email</FormLabel>
							<FormControl>
								<Input placeholder="Your email" defaultValue={user?.email} {...field} />
							</FormControl>
							<FormMessage />
						</FormItem>
					)}
				/>
				<FormField
					control={form.control}
					name="phone_number"
					render={({ field }) => (
						<FormItem>
							<FormLabel>Phone Number</FormLabel>
							<FormControl>
								<Input placeholder="Your phone number" defaultValue={user?.phone_number} {...field} />
							</FormControl>
							<FormMessage />
						</FormItem>
					)}
				/>
				<FormField
					control={form.control}
					name="password"
					render={({ field }) => (
						<FormItem>
							<FormLabel>Password</FormLabel>
							<FormControl>
								<Input type="password" placeholder="New password" {...field} />
							</FormControl>
							<FormMessage />
						</FormItem>
					)}
				/>
				<Button type="submit">Update Account</Button>
			</form>
		</Form>
	);
}